#!/bin/bash
# fonctions.sh
# Auteur : Stéphane Schildknecht
# Some generic functions

# we might expose private data
umask 0077

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#. $SLON/etc/slony_include.h


export TEXTDOMAIN=slonyctl
export TEXTDOMAINDIR=$SLON/i18n
. gettext.sh

#set -x
#################
# Les fonctions #
#################

# Constitution d'un tableau à deux dimensions.
# Cela permet de stocker :
# NoeudX : BASE | HOST | PORT
# Ainsi :
# NODE[$i]=numéro du noeud
# NODE[$1+1]=base
# NODE[$i+2]=host
# NODE[$i+3]=port
# INDEX est un tableau qui permet de savoir à quel indice du tableau NODE
# est stocké le noeud

#################################################
# Begin parsing functions
node (){
	INSTANCE=$1
	nb_node=1
	while read line
	do
	    echo $line | grep -v "^#" | grep "^$INSTANCE\b" > /dev/null
	    if [ $? -eq 0 ] ; then
		BASE=( $line )
		NODE[$nb_node]=${BASE[1]} #Numéro du noeud
    		NODE[$nb_node+1]=${BASE[2]} #Base
    		NODE[$nb_node+2]=${BASE[3]} #Host
		NODE[$nb_node+3]=${BASE[4]} #Port
		INDEX[${BASE[1]}]=$nb_node
    		let nb_node=$nb_node+4
	    fi
	done < $SLON_ETC/bases.h

	let taille_nod=$nb_node-4
	let nb_node=$(($nb_node-1))/4
    return $nb_node
}

# Constitution du tableau des relations entre les noeuds
# RELATION : maitre | esclave
# Ainsi :
# $REL[$i]=maitre
# $REL[$i+1]=esclave
# Le tableau est reconstruit pour chaque set...

relation (){
    MASTER=0
    nb_rel=1
    SET_ID=$1
    # Il va falloir reconstruire les relations set par set...
    # Faut-il stocker le nb_rel par set ?
    while read line
    do
    	tempset=`echo $line | grep -v "^#" | grep "^$INSTANCE\b" | awk '{print $2}'`
    	if [[ $tempset -ne 0 && $tempset -eq $SET_ID ]]; then
	    BASE=( $line )
	    REL[$nb_rel]=${BASE[2]}
	    REL[$nb_rel+1]=${BASE[3]}
	    if [ ${MASTER} -eq 0 ]; then
		MASTER=${BASE[2]}
	    else
    		if [ ${MASTER} -eq ${BASE[3]} ]; then
		    MASTER=${BASE[2]}
    		fi
    	    fi
	    let nb_rel=$nb_rel+2
	fi
    done < $SLON_ETC/relations.h

    let taille_rel=$nb_rel-2
    let nb_rel=$(($nb_rel-1))/2
    return $nb_rel
}

# Mise à jour du fichier de relations
relation_file(){
    CLUSTER=$1
    DB=$2
    HOST=$3
    PORT=$4

    echo "Mise à jour du fichier de relations"

    cp $SLON_ETC/relations.h $SLON_ETC/relations.h.`date +%y%m%d%H`
    grep -v "\b$CLUSTER\b" $SLON_ETC/relations.h.`date +%y%m%d%H` > $SLON_ETC/relations.h
#	echo "" >> $SLON_ETC/relations.h
    echo "# La réplication $CLUSTER" >> $SLON_ETC/relations.h
    psql -t $DB -U$SLONY_USER -p$PORT -h$HOST -c "select E'$CLUSTER  '||sub_set||E'  '||sub_provider||E'  '||sub_receiver from _$INSTANCE.sl_subscribe order by sub_set asc,sub_provider,sub_receiver asc;" | sed -e 's/^ //' | sed -e 's/  /\t/g' >> $SLON_ETC/relations.h

#mv $SLON_ETC/relations.h $SLON_ETC/relations.h.`date +%y%m%d`
#cp $SLON_TEMP/relations.h $SLON_ETC/relations.h
}

test_repli() {
    SEUIL=5
    REPLI="_$1"
    BASE=$2
    USEUR=$SLONY_USER
    HOTE=$3
    PORT=$4
    PF_TAMPON=$SLON_LOG/decalage_slony

    l_retour=0
    for l_noeud in `/usr/bin/psql $BASE -U $USEUR -h $HOTE -p $PORT -t \
                    -c "select no_id from "$REPLI".sl_node order by no_id asc;"`
    do
            l_decalage=`/usr/bin/psql $BASE -U $USEUR -h $HOTE -p $PORT -t \
                    -c "select st_lag_num_events from "$REPLI".sl_status where st_received=$l_noeud;"`

            l_decalage=`expr $l_decalage + 0`
            echo " - $l_decalage transactions pour le noeud $l_noeud" >&2
            if test $l_decalage -gt $SEUIL
            then
    	    l_retour=`expr $l_retour + $l_noeud`
            fi
    done

    touch $PF_TAMPON
    if [ $l_retour -ne 0 ]
    then
            if [ "`cat $PF_TAMPON`" != "`date +%Y%m%d%H`" ]
            then
                    date +%Y%m%d%H>$PF_TAMPON
            fi
    fi

    exit $l_retour
}

moveset(){
    INSTANCE=$1
    SETID=$2
    MASTERNODE=$3
    SLAVENODE=$4

    ${SLON_BIN}/slonik <<_EOF_
	#--
        # Inclusion du fichier <preamble>
        #--
        INCLUDE <${SLON_ETC}/$INSTANCE.preamble>

        try{
	    echo 'unlock $SETID : ';
            UNLOCK SET (
		ID = $SETID,
                ORIGIN = $MASTERNODE );
        }
        on success { echo 'OK' ;}
        on error { echo 'KO' ;}

        try{
	    echo 'move set $SETID : ';
            LOCK SET (
		ID = $SETID,
                ORIGIN = $MASTERNODE ) ;
            echo 'lock set : OK';
            echo 'move set : ';
            MOVE SET (
	        ID = $SETID,
                OLD ORIGIN = $MASTERNODE,
                NEW ORIGIN = $SLAVENODE );
        }
        on error { echo 'KO' ;}
        on success { echo 'OK' ;}
_EOF_
}
#################################################

#################################################
# Begin Sanity checks
function require_file {
  local FILE="$1" ; shift
  local funcname="$0"

  if [ -z "$FILE" ] ; then
	echo $(eval_gettext "ERROR: \$funcname function require a string as argument") >&2
	exit 1
  fi
  if [ ! -e "$FILE" ]; then
	echo $(eval_gettext "Can't find '\$FILE'")
	echo $(gettext      "Please verify your settings.")
	exit 1
  fi
  return 0
}
relations_exist(){
  require_file "${SLON_ETC}/relations.h"
  return 0
}
bases_exist(){
  require_file "${SLON_ETC}/bases.h"
  return 0
}
relbase_exist(){
  relations_exist
  bases_exist
  return 0
}
preamble_exist(){
  local CLUSTER="$1" ; shift
  require_file "${SLON_ETC}/${CLUSTER}.preamble"
  return 0
}

replication_exist(){
  local CLUSTER="$1" ; shift

  relations_exist
  grep "${CLUSTER}" "${SLON_ETC}/relations.h" > /dev/null
  if [ $? -ne 0 ] ; then
	echo $(eval_gettext "Error : \$filename  ")
	echo $(eval_gettext "Cluster '\${CLUSTER}' does not exist in '\${SLON_ETC}/relations.h'")
	echo $(gettext      "Please verify your settings.")
	exit 1
  fi
  return 0
}
# End Sanity checks
#################################################

#################################################
# Begin Error handling
error(){
    CONTEXT=$1
    ERROR=$2
    if [[ x$LANG = xfr* ]]; then
	echo "Une erreur est survenue lors de l'opération \"$CONTEXT\""
    else
	echo "An error occured while \"$CONTEXT\""
    fi
#ERROR 2 : Script file not found
    if [ $ERROR -eq 2 ]; then
        NFFILE=$3
	if [[ x$LANG = xfr* ]]; then
	    echo "Le fichier $NFFILE est introuvable."
        else
            echo "File $NFFILE not found."
	fi
#ERROR 3 : Slonik error
    elif [ $ERROR -eq 3 ]; then
        if [[ x$LANG = xfr* ]]; then
            echo "Erreur Slonik."
        else
            echo "Slonik error."
        fi
#ERROR 4 : Configuration file not found
    elif [ $ERROR -eq 4 ]; then
        if [[ x$LANG = xfr* ]]; then
            echo "Un des fichiers bases.h, relations.h ou preamble est introuvable."
	    echo "Merci de vérifier votre installation."
        else
	    echo "Can't find one of bases.h, relations.h or preamble files."
	    echo "Please verify your settings."
	fi
#ERROR 5 : Undefined replication
    elif [ $ERROR -eq 5 ]; then
	REPLI=$3
	if [[ x$LANG = xfr* ]]; then
            echo "La réplication $REPLI n'est pas définie."
        else
            echo "$REPLI replication is not defined."
        fi
    fi
    return 1
}


# Output debug mode
output_debug(){
	if [ $DEBUG -eq 1 ] ; then echo "DEBUG: $1" ; fi
}

# Exit on error with msg
function exit_error_msg {
	if [ $? -ne 0 ] ; then
		MSG="$1"
		ERRCODE="$2"
		EXT="$3"
		if [ -z "$MSG" ] ; then
			MSG="Unexpected problem"
		fi
		if [ -z "$ERRCODE" ] ; then
			ERRCODE="99"
		fi
		error "${MSG}" "${ERRCODE}" "$EXT"
		exit 1
	fi
}
# End Error handling
#################################################



# create the preamble file for a cluster
function create_preamble {
  local CLUSTER="$1" ; shift
  local FLAG=0

  echo $(eval_gettext "Creation of Preamble file \$CLUSTER") >&2
  if [ x"$CLUSTER" = "x" ]; then
	for cluster in `grep -v "^#" $SLON_ETC/bases.h | awk '{print $1}' | sort -u`
	do
	  create_preamble "$cluster"
	  exit_error_msg "Preamble file creation FAILED, abort."
	  FLAG=1
	done
	if [ $FLAG -eq 0 ] ; then
	  echo $(eval_gettext "You need to define Nodes for your cluster in etc/bases.h") >&2
	  exit 1
	fi
	return 0
  fi
  echo "CLUSTER NAME = $CLUSTER ;" > "${SLON_ETC}/${CLUSTER}.preamble"

  FLAG=0
  while read line
  do
	echo $line | grep -v "^#" | grep "^$CLUSTER\b" > /dev/null
	if [ $? -eq 0 ] ; then
	  base=( $line )
	  cat << TPL  >> "${SLON_ETC}/$CLUSTER.preamble"
NODE ${base[1]} ADMIN CONNINFO = 'dbname=${base[2]} host=${base[3]} port=${base[4]} user=${SLONY_USER}${SLONY_PWD:+ password=$SLONY_PWD}';
TPL
	  FLAG=1
	fi
  done<"$SLON_ETC/bases.h"
  if [ $FLAG -eq 0 ] ; then
	echo $(eval_gettext "You need to define Nodes for your cluster in etc/bases.h") >&2
	rm "${SLON_ETC}/$CLUSTER.preamble"
	exit 1
  fi
  chmod 600 ${SLON_ETC}/$CLUSTER.preamble
  echo $(eval_gettext "... \${SLON_ETC}/\${CLUSTER}.preamble created") >&2
  return 0
}




