#!/bin/bash
# Auteur : Stéphane Schildknecht <sas@postgresql.fr>
# 01_create_init.sh
# Initialisation scripts creation
# 2006-11-17
# MAJ 2007-06-28
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20071216 Bernard Choppy
#    deplacement des fichiers "*.slon" dans $SLON_TEMP
#  - 20100510 SAS
#    Verification presence fichiers
#  - 201006 Cédric
#	 Change configuration init
#	 add gettext - i18n
#	 add templating functions
#	 improve output
#	 clean file
#	 more error handling (do we have nodes defined ?)
#	 add aff_tree output

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "This script will create files for initialising a replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-d, --debug\\tDebug")
  echo ""
}

TEMP=`getopt -n $0 -o d,h,c: -l debug,help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

# TODO rework the getopt and failure case.
DEBUG=0
CLUSTER=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-d|--debug)
	  DEBUG=1
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
# End Sanity checks
#################################################

#################################################
# Begin Real work

# Creation of preamble files
# Be careful, in these files, MASTER and SLAVES are hardcoded.
create_preamble "${CLUSTER:+$CLUSTER}"
exit_error_msg "Preamble file creation FAILED, abort."

#
# Get the cluster name from command line
# or guess it from bases.h configuration file
#
if [ x"$CLUSTER" != "x" ]; then
  GREP="echo $CLUSTER"
else
  GREP="grep -v \"^#\" $SLON_ETC/bases.h | awk '{print \$1}' |sort -u"
fi

output_debug "Find each cluster from commandline or from bases.h :"
output_debug "  $GREP"

#
# For each CLUSTER found
# We call create_slon.sh which construct initialisation scripts.
# These are used to settle up the replication.
#
for CLUSTER in `eval $GREP`
do
  output_debug "${SLON_OUTILS}/create_slon.sh -c $CLUSTER > ${SLON_TEMP}/$CLUSTER.slon"

  ${SLON_OUTILS}/create_slon.sh -c $CLUSTER > ${SLON_TEMP}/$CLUSTER.slon
  exit_error_msg "create_init" 1

  chmod 700 ${SLON_TEMP}/$CLUSTER.slon

  for SETID in `grep "^${CLUSTER}\b" ${SLON_ETC}/relations.h | grep -v "^#" | awk '{print $2}' | sort -u`
  do
	echo $(eval_gettext "Replication tree for SET \${SETID}, CLUSTER \${CLUSTER}:")
	${SLON_OUTILS}/aff_tree.sh -c ${CLUSTER} -s ${SETID}
  done
done


echo $(gettext "First step of replication's initialisation successful.")
echo $(eval_gettext "Next step is ./02_exec_init.sh -c CLUSTER for each cluster in [\$CLUSTER]")
exit 0
# End Real work
#################################################
