#!/bin/bash
# Auteur: Stéphane Schildknecht <sas@postgresql.fr>
# Rev 20090424
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20071216 Bernard Choppy
#    deplacement des fichiers "*.slon" dans $SLON_TEMP
#  - 20090424 SAS
#    Bug in test case
#    per report from Bastian Voigt
#  - 20100510 SAS
#    File existence verification
#  - 201006 Cédric
#	 Change configuration init
#	 add gettext - i18n
#	 clean file

# 02_exec_init.sh
# Launcher for initialisation script

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/

# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo $(eval_gettext "\$filename")
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\t\\tPrint this help")
  echo -e $(gettext   "\\t-c, --cluster\\t\\tThe name of the replication cluster")
  echo -e $(gettext   "\\t-d, --debug\\t\\tDebug")
  echo ""
}

TEMP=`getopt -n $0 -o h,d,c: -l debug,help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

DEBUG=0
CLUSTER=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-d|--debug)
	  DEBUG=1
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" ]; then
  slhelp;
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
LOGFILE="${SLON_LOG}/${CLUSTER}.log"
echo $(eval_gettext "Initialising \${CLUSTER} replication...")
echo $(eval_gettext " LOGFILE: \${LOGFILE}")
output_debug "sh ${SLON_TEMP}/${CLUSTER}.slon > ${LOGFILE} 2>&1"

#
# Exec the initialisation script
#
sh ${SLON_TEMP}/${CLUSTER}.slon > "${LOGFILE}" 2>&1
exit_error_msg "exec_init" 1

echo $(gettext "Replication's initialisation successfull.")
echo $(gettext "You may want to inspect logfiles :")
ls -1 ${SLON_LOG} | grep ${CLUSTER}.*log
echo $(gettext "in order to check complitness of replication.")
exit 0
# End Real work
#################################################
