#!/bin/bash
# 101_create_propagate.sh
# Allows one to propagate an SQL script
# on every node of a replication, outside of slonik.
# May be used to propagate a table creation, or an index, for cluster

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Execution of a SQL script on every node, outside of slony")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-f, --file\\tThe SQL script")
  echo ""
}

TEMP=`getopt -n $0 -o h,c:f: -l help,cluster:,file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$FILE" = "x" ]; then
  slhelp
  exit 1
fi

# Does FILE exist?
if [ ! -e $FILE ]; then
  error "Propagation" 2 $FILE
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
echo $(eval_gettext "Execution of \$FILE on every node of \$CLUSTER replication...")

${SLON_OUTILS}/slony_propagate.sh -c $CLUSTER -f $FILE > "${SLON_TEMP}/${CLUSTER}_propagate.slon"
exit_error_msg error "slony_propagate"

chmod 700 ${SLON_TEMP}/${CLUSTER}_propagate.slon

echo $(gettext "OK")
exit 0
# End Real work
#################################################
