#!/bin/bash
# Auteur : Stéphane Schildknecht
# 102_exec_propagate.sh
# 2009/05/11
# Modifications :
#  - 20100510 SAS
#    File existence verification

# Script de lancement d'exécution de script SQL
# en dehors de Slony, sur tous les noeuds de la réplication
## EN: Allows one to propagate an SQL script
## on every node of a replication, outside of slonik.
## May be used to propagate a table creation, or an index, for cluster

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Execution of a SQL script on every node, outside of slony")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo ""
}

TEMP=`getopt -n $0 -o h,c: -l help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" ]; then
  slhelp
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
LOGFILE="${SLON_LOG}/${CLUSTER}_prop.log"
echo $(eval_gettext "Execution of \$FILE on every node of \$CLUSTER replication...")
echo $(eval_gettext " LOGFILE: \${LOGFILE}")

${SLON_TEMP}/${CLUSTER}_propagate.slon > "${LOGFILE}" 2>&1
exit_error_msg $0 1

echo $(gettext "OK")
exit 0
# End Real work
#################################################
