#!/bin/bash
# SAS 2009/04/15
# Modification:
#  - 20100510 SAS
#    File existence verification
#  - 20110413 SAS
#    Cosmetic patch

# 111_create_dropobj.sh
# Creation of the script to drop objects from a running
# replication

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Dropping objects from a replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-f, --file\\tThe file containing the objects")
  echo ""
}

TEMP=`getopt -n $0 -o h,f:c: -l help,cluster:,file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$FILE" = "x" ]; then
  slhelp ;
  exit 1
fi

# Does FILE exist?
if [ ! -e $FILE ]; then
  error $0 2 $FILE
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
echo $(gettext "Creating Slonik Drop Objects script...")

${SLON_OUTILS}/slony_dropobj.sh -c $CLUSTER -f $FILE > "${SLON_TEMP}/${CLUSTER}_dropobj.slon"
exit_error_msg "dropobj" 1

chmod 700 ${SLON_TEMP}/${CLUSTER}_dropobj.slon

echo $(gettext "OK")
exit 0
# End Real work
#################################################
