#!/bin/bash
# Modifications :
#  - 20100510 SAS
#    File existence verification

# 112_exec_dropobj.sh
# Slonik scripts to drop objects from an existing set of replication
# Script de suppression d'objets d'une réplication

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Dropping objects from a replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo ""
}

TEMP=`getopt -n $0 -o h:s:c: -l help,set:,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done


if [ x"$CLUSTER" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
LOGFILE="${SLON_LOG}/${CLUSTER}_dropobj.log"
echo $(gettext      "Dropping objects...")
echo $(eval_gettext " LOGFILE: \${LOGFILE}")

/bin/bash ${SLON_TEMP}/${CLUSTER}_dropobj.slon > "${LOGFILE}" 2>&1
exit_error_msg $0

echo $(gettext "OK")
exit 0
# End Real work
#################################################
