#!/bin/bash
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20071216 Bernard Choppy
#    deplacement des fichiers "*.slon" dans $SLON_TEMP
#  - 201006 Cédric
#	 Change configuration init
#	 add gettext - i18n
#	 improve output
#	 clean file
#	 better handling of FILE

# 11_create_addobj.sh
# Creation of the script to add objects to an already runnning
# replication

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-s, --set\\tThe number of the set")
  echo -e $(gettext   "\\t-f, --file\\tThe file containing the objects names")
  echo ""
}

TEMP=`getopt -n $0 -o f:s:c:h -l help,set:,cluster:,file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-s|--set)
	  shift
	  SET="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$SET" = "x" -o x"$FILE" = "x" ]; then
  slhelp ;
  exit 1
fi

if [ ! -e $FILE ]; then
  error $0 2 $FILE
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
echo $(gettext "Creating Slonik Add Objects script...")

${SLON_OUTILS}/slony_addobj.sh -c $CLUSTER -s $SET -f $FILE > "${SLON_TEMP}/${CLUSTER}_${SET}_addobj.slon"
exit_error_msg error "slony_addobj" 1

chmod 700 ${SLON_TEMP}/${CLUSTER}_${SET}_addobj.slon

echo $(gettext "OK")
exit 0
# End Real work
#################################################
