#!/bin/bash
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20071216 Bernard Choppy
#    deplacement des fichiers "*.slon" dans $SLON_TEMP
#  - 201006 Cédric
#	 Change configuration init
#	 add gettext - i18n
#	 clean file

# 21_create_addnode.sh
## EN: Adding a node to an already active replication
# Subscription is done regarding relations.h, there's no need
# to precise the set.
## FR : Ajout d'un noeud à une réplication active
# La souscription est effectuée conformément au fichier
# relations.h, il n'est donc pas nécessaire de préciser le
# set de réplication.

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Adding a node to an active replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-n, --node\\tThe number of the node")
  echo ""
}

TEMP=`getopt -n $0 -o c:n:h -l help,cluster:,node: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
NUM=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-n|--node)
	  shift
	  NUM="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$NUM" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
echo $(eval_gettext "Creating script to add the node \$NUM...")

/bin/bash ${SLON_OUTILS}/slony_addnode.sh -c $CLUSTER -n $NUM > "${SLON_TEMP}/${CLUSTER}_${NUM}_add.slon"
exit_error_msg "slony_addnode" 1

chmod 700 ${SLON_TEMP}/${CLUSTER}_${NUM}_add.slon

echo $(gettext "OK")
exit 0
# End Real work
#################################################
