#!/bin/bash
# Auteur : Stéphane Schildknecht
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20071216 Bernard Choppy
#    deplacement des fichiers "*.slon" dans $SLON_TEMP

# 31_create_set.sh
## FR : Création du script d'ajout d'un set à une réplication
## EN: Creation of the script for adding a set to a replication


#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Creating script to add a set to an existing replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-s, --set\\tThe number of the set to be created")
  echo ""
}

TEMP=`getopt -n $0 -o c:s:h -l help,cluster:,set: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|-help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-s|--set)
	  shift
	  SET="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$SET" = "x" ]; then
  slhelp ;
  exit 1
fi
# End help, getopt and handle case
#################################################

### Seems like this part is useless
### FR : Creation des fichiers a inclure dans les scripts slonik
## Attention ! Ces scripts codent en dur les maitres et esclaves
### EN: Creation of preamble files. Be careful, they hard code
## master and slaves
#if [[ x$LANG = xfr* ]]; then
#    echo "Création des fichiers de préambule..."
#else
#    echo "Creation of preamble files..."
#fi
#
#${SLON_OUTILS}/create_preamble.sh ${CLUSTER:+-c $CLUSTER}
#if [ $? -ne 0 ]; then
#    exit_on_error "create_preamble" 1
#fi

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
echo $(eval_gettext "Creation of script to add \$SET to \$CLUSTER...")

${SLON_OUTILS}/create_slon.sh -c $CLUSTER -s $SET > "${SLON_TEMP}/${CLUSTER}_${SET}.slon"
exit_error_msg "create_slon" 1

chmod 700 ${SLON_TEMP}/${CLUSTER}_$SET.slon
echo $(gettext "OK")
exit 0
# End Real work
#################################################
