#!/bin/bash
# Auteur : Stéphane Schildknecht
# 2008/04/23

# 42_exec_exec.sh
## FR : Script de lancement d'exécution de script SQL
## EN: Execution of sql through slonik


#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Execute a SQL script into a replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-s, --set\\tThe set number")
  echo ""
}

TEMP=`getopt -n $0 -o h:c:s: -l help,cluster:,set: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-s|--set)
	  shift
	  SET="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$SET" = "x" ]; then
  slhelp
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
LOGFILE="${SLON_LOG}/${CLUSTER}_${SET}_exec.log"
echo $(eval_gettext "Executing DDL modifications on set \$SET (replication \$CLUSTER)...")
echo $(eval_gettext " LOGFILE: \${LOGFILE}")

${SLON_TEMP}/${CLUSTER}_${SET}_execute.slon > "${LOGFILE}" 2>&1
exit_error_msg $0 1

echo $(gettext "OK")
exit 0
# End Real work
#################################################
