#!/bin/bash
# 61_create_subscribe.sh
# Creation of the script to execute SQL to an already runnning
# replication

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Re-subscribing replication regarding relations.h file")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo ""
}

TEMP=`getopt -n $0 -o c:h -l help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x"  ]; then
  slhelp ;
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
echo $(eval_gettext "Re-subscribing replication \$CLUSTER...")

${SLON_OUTILS}/slony_subscribe.sh -c $CLUSTER > "${SLON_TEMP}/${CLUSTER}_subscribe.slon"
exit_error_msg error "slony_subscribe" 1

chmod 700 ${SLON_TEMP}/${CLUSTER}_subscribe.slon

echo $(gettext "OK")
exit 0
# End Real work
#################################################
