#!/bin/bash
# Auteur : Stéphane Schildknecht
# 2008/04/23
# MAJ 2007-06-28
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20071216 Bernard Choppy
#    deplacement des fichiers "*.slon" dans $SLON_TEMP

# 82_exec_switch.sh
## FR : Bascule contrôlée entre un noeud et l'un de ses esclaves
## EN: Switchover between a node and one of his slave

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Switchover between a node and one of his slaves")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-f, --failed\\tThe failed node (old provider)")
  echo -e $(gettext   "\\t-b, --backup\\tThe backup node (new provider)")
  echo ""
}

TEMP=`getopt -n $0 -o c:f:b:h -l help,cluster:,failed:,backup -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
FAILED=""
BACKUP=""
while [ $# -ge 1 ]; do
  case "$1" in
	--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-f|--failed)
	  shift
	  FAILED="$1"
	  ;;
	-b|--backup)
	  shift
	  BACKUP="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$FAILED" = "x" -o x"$BACKUP" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work
LOGFILE="${SLON_LOG}/${CLUSTER}_switch.log"

echo $(eval_gettext "\$CLUSTER switchover : from \$FAILED to \$BACKUP...")
echo $(eval_gettext " LOGFILE: \${LOGFILE}")

${SLON_OUTILS}/slony_switch.sh -c $CLUSTER -f $FAILED -b $BACKUP > "${LOGFILE}" 2>&1
exit_error_msg "slony_switch.sh"

echo $(gettext "OK")
exit 0
# End Real work
#################################################
