#!/bin/bash
# Auteur : Stéphane Schildknecht
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#

# aff_tree.sh
# Print relations tree

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-s, --set\\tThe number of the set")
  echo ""
}

TEMP=`getopt -n $0 -o c:s:h -l help,set:,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
while [ $# -ge 1 ]; do
  case "$1" in
	--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-s|--set)
	  shift
	  SET="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$SET" = "x" ]; then
  slhelp;
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

relation $SET

trouve=0
for (( j=1 ; j <= taille_rel ; j+=2 )); do
  if [ ${REL[$j]} -eq ${REL[1]} ]; then
	if [ $trouve -gt 0 ]; then
	  echo -n "\--"
	else
	  echo -n ${REL[1]}--
	fi
	let trouve=$trouve+1
	${SLON_OUTILS}/tree.sh -c $CLUSTER -s $SET -p ${REL[$j]} -f ${REL[$j+1]}
  fi
done

exit 0
# End Real work
#################################################
