#!/bin/bash
# Auteur : Stephane Schildknecht
# 2007-01-12
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#

# slony_addnode.sh
# Script d'ajout d'un noeud à une réplication
## EN: Adding a node to a replication network

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Adding a node to a replication network")
  echo -e $(gettext   "\\tbases.h, relations.h and preamble files have to be up-to-date")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-n, --node\\tThe number of the node")
  echo ""
}

TEMP=`getopt -n $0 -o c:n:h -l help,cluster:,node: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
NODE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|-help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-n|--node)
	  shift
	  NODE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$NODE" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work


NODENUM=$NODE

# Reconstruction des informations concernant les noeuds
## EN: node array
node $CLUSTER

SLAVENODE=$NODENUM
SLAVEBASE=${NODE[${INDEX[$NODENUM]}+1]}
SLAVEHOST=${NODE[${INDEX[$NODENUM]}+2]}
SLAVEPORT=${NODE[${INDEX[$NODENUM]}+3]}

## EN:
# 1. We add PL/pgSQL
# 2. We drop any existing slony information
# 3. We recreate the preamble file

tpl_sh_shabang
tpl_sh_require_plpgsql "$SLAVEBASE" "$SLAVEHOST" "$SLAVEPORT"
tpl_sh_uninstall_slon_schema "$SLAVEBASE" "$SLAVEHOST" "$SLAVEPORT" "$CLUSTER"
create_preamble "$CLUSTER"
cat << EOF
if [ \$? -ne 0 ]; then
  echo "Can't create preamble file."
  exit 1
fi
EOF
# Arbitrairement, on effectue le store node par rapport au premier set de la réplication
# si le noeud à ajouter en fait partie
## EN: We store the node node regarding the first set of replication, if
# the node is part of that set.

tpl_sh_slonik_begin_eof
tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"

STORE=0
GREP_SET="grep \"^$CLUSTER\b\" $SLON_ETC/relations.h | grep -v \"^#\" | awk '{print \$2}' | sort -u"
for SETID in `eval $GREP_SET` ; do
  relation $SETID

  for (( j=1 ; j <= taille_rel ; j+=2 )); do
	if [ ${REL[$j+1]} -eq $SLAVENODE ]; then
	  if [ $STORE -eq 0 ]; then
		tpl_slonik_drop_node $SLAVENODE $MASTER "Drop node $SLAVENODE"
		# TODO no exit 1 on error ?
		cat <<EOF
	on success{ echo 'OK';}
	on error{ echo 'no $SLAVENODE';}
EOF

		tpl_slonik_store_node $SLAVENODE $MASTER $SLAVEBASE $SLAVEHOST \
							  $CLUSTER "Store node $SLAVENODE"

		tpl_slonik_success_error "$(gettext 'Success')" \
								 "$(gettext 'Failed !!!')"

		#Liens entre un noeud et les autres
		## EN: Creating links between nodes
		for (( k=1 ; k <= taille_nod ; k+=4 )); do
		  NODE2=${NODE[$k]}
		  BASE2=${NODE[$k+1]}
		  HOST2=${NODE[$k+2]}
		  PORT2=${NODE[$k+3]}

		  if [ $NODE2 -ne $SLAVENODE ]; then
			tpl_slonik_store_path "$NODE2" "$SLAVENODE" \
								  "$BASE2" "$HOST2" "$PORT2"
			tpl_slonik_store_path "$SLAVENODE" "$NODE2" \
								  "$SLAVEBASE" "$SLAVEHOST" "$SLAVEPORT"
		  fi
		done

		tpl_sh_slonik_end_eof
		echo "# Starting slon daemons for new node"
		tpl_sh_start_slon_daemons ${CLUSTER} ${SLAVENODE} $SLAVEBASE \
								  $SLAVEHOST $SLAVEPORT
		cat << EOF
echo "Slony slave started on `hostname` : $SLAVENODE"
EOF

		# Node is up and running
		STORE=1
	  fi

# Souscriptions...
## EN: Let's subscribe
#for (( j=1 ; j <= taille_rel ; j+=2 )); do
#    if [ ${REL[$j+1]} -eq $SLAVENODE ]; then
	  let mtr=${INDEX[${REL[$j]}]}     #MAITRE
	  let slv=${INDEX[${REL[$j+1]}]}  #ESCLAVE

	  if [ ${REL[$j]} -ne ${MASTER} ]; then
		tpl_sh_while_subscribe ${REL[$j]} ${MASTER} \
							   ${NODE[$mtr+1]} ${NODE[$mtr+2]} \
							   ${NODE[$mtr+3]} $CLUSTER ${NODE[$mtr]} \
							   $SETID
	  fi

	  cat <<EOF
# Il faut maintenant informer les bases de la réplication
## EN: Let's subscribe
echo "Souscription Set $SETID :"
EOF
	  tpl_sh_slonik_begin_eof
	  tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"
	  tpl_slonik_subscribe_set $SETID ${REL[$j]} $SLAVENODE \
							   "Node $SLAVENODE subscribes set $SETID on ${REL[$j]}"
	  tpl_slonik_success_error "Successfull" "Failled !!!"
	  echo "#sleep (seconds = 300);"
	  tpl_sh_slonik_end_eof
	fi
  done
done

exit 0
# End Real work
#################################################

