#!/bin/bash
# Auteur : Stephane Schildknecht
# Rev 20070419
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20080716 Stephane Schildknecht
#    Correction pour prendre en compte les numéros réels
#    des noeuds
#

# slony_addobj.sh
# Script d'ajout de tables/séquences à une réplication
## EN: Adding objects to a replication


#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication instance name")
  echo -e $(gettext   "\\t-s, --set\\tThe number of the set")
  echo -e $(gettext   "\\t-f, --file\\tThe file containing objects")
  echo ""
}

TEMP=`getopt -n $0 -o c:s:f:h -l help,cluster:,set:,file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

INSTANCE=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  INSTANCE="$1"
	  ;;
	-s|--set)
	  shift
	  SET="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$INSTANCE" = "x" -o x"$SET" = "x" -o x"$FILE" = "x" ]; then
  slhelp;
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $INSTANCE
replication_exist $INSTANCE
# End Sanity checks
#################################################

#################################################
# Begin Real work

#
# Nodes array
#
node $INSTANCE ;

#
# relations array
#
relation $SET ;

# FILE containing names of the objects to add (tables and sequences)
. $FILE

CLUSTERID=${MASTER}

tpl_sh_shabang
# TODO usefull sourcing ?
# This is because we use error() (not sure it work anyway)
# we must remove that once the script is using gettext
# produced script must be generated in the apropriate language
echo ". $SLON_ETC/fonctions.sh"
tpl_sh_slonik_begin_eof
tpl_slonik_include_preamble "${SLON_ETC}/$INSTANCE.preamble"

cat <<EOF
echo 'Set creation: ';
try{
EOF

tpl_slonik_create_set 99 $CLUSTERID "**Temp set**"

echo "# Tables"
# Récupération du dernier numéro utilisé dans la numérotation des tables
## EN: What is the max tab_id in replication?
# FIXME : We may have a different max(tab_id) in another node, in case of
# crossing sets of replication
TABLEID=`psql ${NODE[2]} -U ${SLONY_USER} -p${NODE[4]} -h${NODE[3]} -t -c "select max(tab_id)+1 from \"_${INSTANCE}\".sl_table;"| awk '{print $1}'`

tnum=$TABLEID
for table in `echo $TAB`; do
  tpl_slonik_set_add_table 99 $CLUSTERID $tnum $table
  let "tnum=tnum+1"
done

echo "# Sequences"
# Récupération du dernier numéro utilisé dans la numérotation des séquences
## EN: What is the max seq_id in replication?
# FIXME : We may have a different max(seq_id) in another node, in case of
# crossing sets of replication
SEQID=`psql ${NODE[2]} -U ${SLONY_USER} -p${NODE[4]} -h${NODE[3]} -t -c "select max(seq_id)+1 from \"_${INSTANCE}\".sl_sequence;"| awk '{print $1}'`

snum=$SEQID
for seq in `echo $SEQ`; do
  tpl_slonik_set_add_sequence 99 $CLUSTERID $snum $seq
  let "snum=snum+1"
done

echo "}"
tpl_slonik_success_error "Success" "Failed !"

echo "exit 0;"
tpl_sh_slonik_end_eof

cat << EOF
if [ \$? -ne 0 ]; then
  error "CREATE SET" 3;
  exit 1
fi
EOF

# Pour tous les noeuds ayant souscrits au premier set
# le noeud souscrit le nouveau set. Lorsque tous les noeuds ont souscrits,
# il est alors possible de fusionner les deux sets.
## EN: We have to subscribe every node that has subscribed to
# destination set.
for (( i=1 ; i <= taille_rel ; i+=2 )); do
  MASTERNODE=${REL[$i]}
  SLAVENODE=${REL[$i+1]}
  mtr=${INDEX[${REL[$i]}]}
  slv=${INDEX[${REL[$i+1]}]}
  cat <<EOF

echo "$SLAVENODE subscribes set 99:"
EOF
  if [ $MASTERNODE -ne $MASTER ]; then
	tpl_sh_while_subscribe $MASTERNODE $MASTER \
						   ${NODE[$mtr+1]} ${NODE[$mtr+2]} ${NODE[$mtr+3]}\
						   $INSTANCE ${NODE[$mtr]} 99
  fi

  tpl_sh_slonik_begin_eof
  tpl_slonik_include_preamble "${SLON_ETC}/$INSTANCE.preamble"
  tpl_slonik_subscribe_set \
	  99 ${REL[$i]} $SLAVENODE \
	  "Node $SLAVENODE subscribes set 99"
  tpl_slonik_success_error "Success" "Failed !"
  tpl_slonik_sync_id ${REL[$i]}
  tpl_slonik_wait_for_event ${REL[$i]} $SLAVENODE ${REL[$i]}
  echo "exit 0;"
  tpl_sh_slonik_end_eof

  cat <<EOF

if [ \$? -ne 0 ]; then
  error "SUBSCRIBE SET" 3;
  exit 1
fi
EOF
done


cat <<EOF
# Arbitrary timing
sleep 120

# Il faut maintenant fusionner les deux sets
## Let's merge sets
echo "Merge sets:"
EOF
tpl_sh_slonik_begin_eof
tpl_slonik_include_preamble "${SLON_ETC}/$INSTANCE.preamble"

tpl_slonik_merge_set $SET 99 $CLUSTERID

tpl_slonik_success_error "$(gettext 'Merge set : Success')" \
						   "$(gettext 'Merge set : Failed !!!')"

echo "exit 0;"
tpl_sh_slonik_end_eof

cat <<EOF

if [ \$? -ne 0 ]; then
  error "MERGE SET" 3;
  exit 1
fi

exit 0
EOF

exit 0
# End Real work
#################################################
