#!/bin/bash
# REV dalibo 20070417
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#

# slony_ctl.sh
## FR : Contrôle de la réplication
## EN: Managing replication

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

# TODO do we want those path for functions, really ?
# TODO prevent multiple load of sources files.
. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

# End initialise configuration
#################################################

#################################################
# Begin Real work

slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication instance name")
  echo -e $(gettext   "\\tstart|stop|restart|status|clean  The action")
  echo ""
}

stop_slon() {
  local my_command=`tpl_sh_kill_slon_daemons "$CLUSTERNAME"`
  eval "$my_command"
}

start_slon() {
  echo "Starting $CLUSTERNAME replication..."

  for (( i=1 ; i <= taille_nod ; i+=4 )); do
	${SLON_BIN}/slon -f $SLON_ETC/slon.cfg ${CLUSTERNAME} "dbname=${NODE[$i+1]} host=${NODE[$i+2]} port=${NODE[$i+3]} user=${SLONY_USER}${SLONY_PWD:+ password=$SLONY_PWD}" >>${SLON_LOG}/${CLUSTERNAME}_${NODE[$i+1]}_${NODE[$i]}.log 2>&1 &
	if [ $? -eq 0 ] ; then
	  echo "Slon daemons started on `hostname` : ${NODE[$i]}"
	else
	  echo " LOGFILE: ${SLON_LOG}/${CLUSTERNAME}_${NODE[$i+1]}_${NODE[$i]}.log"
	  error "START"
	  exit 1
	fi
  done
}

clean_sl(){
  echo "Cleaning sl_nodelock..."
  for (( i=1 ; i <= taille_nod ; i+=4 )); do
	psql -U $SLONY_USER ${NODE[$i+1]} -h ${NODE[$i+2]} -p ${NODE[$i+3]} -c "delete from _$CLUSTERNAME.sl_nodelock;"
	echo " Table Cleaned on ${NODE[$i]}, ${NODE[$i+2]}"
  done
}

TEMP=`getopt -n $0 -o c:h -l help,cluster:,start,stop,restart,clean,status -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

INSTANCE=""
SET=""
while [ $# -ge 1 ]; do
  case "$1" in
	--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  INSTANCE="$1"
	  ;;
	--)
	  shift
	  ACTION="$1"
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$INSTANCE" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $INSTANCE
replication_exist $INSTANCE
# End Sanity checks
#################################################

#################################################
# Begin Real work

node $INSTANCE

CLUSTERNAME=$INSTANCE

case $ACTION in
  start)
	start_slon
	exit 0
	;;
  stop)
	stop_slon
	exit 0
	;;
  restart)
	echo -n "Restarting $CLUSTERNAME replication :"
	stop_slon
	clean_sl
	start_slon
	exit 0
	;;
  status)
	echo "$CLUSTERNAME replication status: "
	${SLON_OUTILS}/slony_repstat.sh -c $CLUSTERNAME
	exit 0
	;;
  clean)
	echo "Cleaning sl_nodelock tables : "
	clean_sl
	exit 0
	;;
  *)
	# Print help
	slhelp
	exit 1
	;;
esac

exit 0
# End Real work
#################################################
