#!/bin/bash
# Auteur : Stephane Schildknecht
# 2009/04/19

# slony_dropobj.sh
# Script de suppression de tables/sÃ©quences d'une rÃ©plication
## EN: Dropping objects from a replication

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Dropping objects from a running replication")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-f, --file\\tThe file containing objects' name")
  echo ""
}

TEMP=`getopt -n $0 -o c:f:h -l help,cluster:file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  shift
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$FILE" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

# nodes array
node $CLUSTER ;

# FILE contains names of the objects to drop
. $FILE

tpl_sh_shabang
tpl_sh_slonik_begin_eof
tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"

cat << EOF
echo 'Table suppression: ';
try{
  # Tables
  echo 'Tables ?';
EOF
## We have to know the number of the originating node
## Is there a better way than scanning all sets to get master node?
## Or to query every node to until we find the object?
DROPTABLES=""
MASTERNODE=0
for table in `echo $TAB`; do
## First, we get the id of the table and the master node for the set the table
## belongs to
  for (( k=1 ; k <= taille_nod ; k+=4 )); do
	NODE2=${NODE[$k]}
	BASE2=${NODE[$k+1]}
	HOST2=${NODE[$k+2]}
	PORT2=${NODE[$k+3]}

	TABLEID=`psql $BASE2 -U ${SLONY_USER} -p$PORT2 -h$HOST2 -t -c "select tab_id from \"_${CLUSTER}\".sl_table where tab_relname='${table##*.}' and tab_nspname='${table%%.*}';"| awk '{print $1}'`

	if [ ! -z $TABLEID ]; then
	  MASTERNODE=`psql $BASE2 -U ${SLONY_USER} -p$PORT2 -h$HOST2 -t -c "select set_origin from \"_${CLUSTER}\".sl_set where set_id = (select tab_set from \"_${CLUSTER}\".sl_table where tab_id=$TABLEID);"| awk '{print $1}'`
	  echo "  echo ' - ${table##*.}';"
	  tpl_slonik_set_drop_table $MASTERNODE $TABLEID
	  break;
	fi
  done # for (( k=1 ; k <= taille_nod ; k+=4 )); do
done # for table in `echo $TAB`; do
echo "}"
tpl_slonik_success_error "Success" "Failed !"

cat << EOF
echo 'Sequence suppression: ';
try{
  # Sequences
  echo 'Sequences ?';
EOF
# La mÃªme chose pour les sÃ©quences
## We do the same for sequences
DROPSEQ=""
MASTERNODE=0
for seq in `echo $SEQ`; do
## Same here... I wish I don't have to parse all nodes...
  for (( k=1 ; k <= taille_nod ; k+=4 )); do
	NODE2=${NODE[$k]}
	BASE2=${NODE[$k+1]}
	HOST2=${NODE[$k+2]}
	PORT2=${NODE[$k+3]}

	SEQID=`psql $BASE2 -U ${SLONY_USER} -p$PORT2 -h$HOST2 -t -c "select seq_id from \"_${CLUSTER}\".sl_sequence where seq_relname='${seq##*.}' and seq_nspname='${seq%%.*}';"| awk '{print $1}'`

	if [ ! -z $SEQID ]; then
	  MASTERNODE=`psql $BASE2 -U ${SLONY_USER} -p$PORT2 -h$HOST2 -t -c "select set_origin from \"_${CLUSTER}\".sl_set where set_id = (select seq_set from \"_${CLUSTER}\".sl_sequence where seq_id=$SEQID);"| awk '{print $1}'`
	  echo "  echo ' - ${seq##*.}';"
	  tpl_slonik_set_drop_sequence $MASTERNODE $SEQID
	  break;
	fi
  done # for (( k=1 ; k <= taille_nod ; k+=4 )); do
done # for seq in `echo $SEQ`; do
echo "}"
tpl_slonik_success_error "Success" "Failed !"
echo "exit 0;"

tpl_sh_slonik_end_eof

exit 0
# End Real work
#################################################
