#!/bin/bash
# Auteur : Stephane Schildknecht
# Rev 20090424
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#  - 20090429
#    Bug in testing existence of preamble file
#    per report of Bastian Voigt

# slony_execute.sh
# Script de propagation de scripts DDL
## EN: Propagating DDL scripts

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-s, --set\\tThe number of the set")
  echo -e $(gettext   "\\t-f, --file\\tThe SQL script")
  echo ""
}

TEMP=`getopt -n $0 -o c:s:f:h -l help,cluster:,set:,file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FILE=""
while [ $# -ge 1 ]; do
  case "$1" in
	--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-s|--set)
	  shift
	  SET="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

# FIXME We could avoid set number when replication involves a single one
if [ x"$CLUSTER" = "x" -o x"$SET" = "x" -o x"$FILE" = "x" ]; then
  slhelp
  exit 1
fi

if [ `dirname $FILE` = "." ]; then
  FILE=`pwd`/$FILE
fi

if [ ! -e $FILE ]; then
  error $0 2 $FILE
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

relation $SET

tpl_sh_shabang
tpl_sh_slonik_begin_eof
tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"

cat << EOF
#--
# Mise à jours des schémas
# Schema modification
#--
EOF

tpl_slonik_try_execute_script $SET $FILE $MASTER
tpl_slonik_success_error "Success" "Failed !"

echo "exit 0;"
tpl_sh_slonik_end_eof

cat <<EOF

if [ \$? -ne 0 ]; then
  error "EXECUTE SCRIPT" 3;
  exit 1
fi

exit 0
EOF

exit 0
# End Real work
#################################################

