#!/bin/bash
# Auteur : Stephane Schildknecht
# 2007-01-12
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
# - 200800401 SAS
#    Lors de la suppression d'un noeud vérification qu'il n'a plus d'esclave
#    Ses esclaves souscrivent à son maître

# slony_fail.sh
## FR :  Script de bascule lorsqu'un maître tombe de manière
# incontrôlée.
# Le maître est supprimé de la réplication, l'esclave prend
# la relève
# Si le noeud n'a pas d'esclave, il est supprimé
# Il s'agit de supprimer le noeud donné en paramètre et d'utiliser son premier esclave
# ou BACKUP s'il est fourni

## EN: Failover script. Failed node is dropped.
# Backup node takes his place. When no backup node, then
# failed node is simply droppped.

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Switchover a node and one of his slave, or drop that node")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-f, --failed\\tThe failed node (old provider)")
  echo -e $(gettext   "\\t-b, --backup\\tThe backup node (not mandatory)")
  echo ""
}

TEMP=`getopt -n $0 -o c:f:b:h -l help,cluster:,failed:,backup: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
SET=""
FAILED=""
BACKUP=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-f|--failed)
	  shift
	  FAILED="$1"
	  ;;
	-b|--backup)
	  shift
	  BACKUP="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$FAILED" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

MASTERNODE=$FAILED

node $CLUSTER
MASTERDB=${NODE[${INDEX[$MASTERNODE]}+1]}
MASTERHOST=${NODE[${INDEX[$MASTERNODE]}+2]}
MASTERPORT=${NODE[${INDEX[$MASTERNODE]}+3]}

SUPER=0
GREP_SET="grep \"^$CLUSTER\b\" $SLON_ETC/relations.h | grep -v \"^#\" | awk '{print \$2}' | sort -u"
for SETID in `eval $GREP_SET` ; do
  relation $SETID
  echo "set : $SETID"

## FR : MASTER est le maître du set, MASTERNODE, le noeud à supprimer
# Si on supprime le noeud principal, pas de resouscription à effectuer
## EN: MASTER is set master, MASTERNODE is the node to drop.
# If MASTER is to be dropped, no resubscription occurs.
  if [ $MASTER -eq $MASTERNODE ]; then
	SUPER=1
	break;
  else
## FR : Récupération du maître
## EN: Get MASTER
	for (( j=1 ; j <= taille_rel ; j+=2 )); do
	  if [ ${REL[$j+1]} -eq $MASTERNODE ]; then
		OLDMASTER=${REL[$j]}

  ## FR : Si le noeud à supprimer a un maître et des esclaves, on le shinte en
  # souscrivant ses esclaves à son maître
  # Avant de supprimer le noeud, il faut basculer ses souscripteurs sur le
  # noeud auquel il souscrivait lui-même
  ## EN: Before dropping a node, resubscribe is slaves to his master.

		for (( k=1 ; k <= taille_rel ; k+=2 )); do
		  if [ ${REL[$k]} -eq $MASTERNODE ]; then
			SLAVENODE=${REL[$k+1]}

			echo "$SLAVENODE subscribes $OLDMASTER"
			${SLON_BIN}/slonik <<_EOF_
`tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"`
`tpl_slonik_subscribe_set $SETID $OLDMASTER $SLAVENODE \
						  "$SLAVENODE subscribes $OLDMASTER"`
`tpl_slonik_success_error "$SLAVENODE -> $MASTER : OK" \
						  "Subscription Failled !!!"`
_EOF_
		  fi
		done
	  fi
	done
  fi
done

SLAVENODE=${BACKUP:-$MASTER}
echo slavenode : $SLAVENODE
MASTERNODE=$FAILED

if [ $SUPER -eq 1 ]; then
  ${SLON_BIN}/slonik <<_EOF_
`tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"`
`tpl_slonik_try_failover $MASTERNODE $SLAVENODE`
`tpl_slonik_success_error "$MASTERNODE -> $SLAVENODE : OK" \
						  "Failover Failed !!!"`
exit 0 ;
_EOF_
fi


## FR :Suppression physique de MASTERNODE du réseau de réplication
## EN: MASTERNODE is dropped
${SLON_BIN}/slonik <<_EOF_
`tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"`
`tpl_slonik_sync_id $SLAVENODE`
`tpl_slonik_wait_for_event "all" "all" $SLAVENODE`
`tpl_slonik_drop_node $MASTERNODE $SLAVENODE "Drop node $MASTERNODE :"`
`tpl_slonik_success_error "Drop $MASTERNODE : OK" \
						  "Drop $MASTERNODE Failed !!!"`
exit 0;
_EOF_

# Slonik does not stop slon daemons. We do.
my_command=`tpl_sh_kill_slon_daemons "$CLUSTER"`
eval "$my_command"

echo <<EOF
Node $MASTERNODE has been dropped. Don't forget to update bases.h and relations.h.
EOF


exit 0
# End Real work
#################################################
