#!/bin/bash
# Auteur : Stéphane Schildknecht

# SAS 20071219
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#

# slony_path.sh
## FR : Script de recréation des chemins de connexion entre
# les noeuds d'une réplication.
## EN: Script to recreate connection pathes between nodes

# Synopsis :
# slony_path.sh -c <instance>

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "recreating connection information between nodes")
  echo $(gettext      "Be careful that all combinations are created")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication instance name")
  echo ""
}

TEMP=`getopt -n $0 -o c:h -l help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

INSTANCE=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|---help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  INSTANCE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit
	  ;;
  esac
  shift

done

if [ x"$INSTANCE" = "x" ]; then
  slhelp
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $INSTANCE
replication_exist $INSTANCE
# End Sanity checks
#################################################

#################################################
# Begin Real work
node $INSTANCE

tpl_sh_shabang
echo "# Slonik script to recreate path information"

tpl_sh_slonik_begin_eof

echo "# Preamble file: contains all useful information"
echo "# about nodes"
tpl_slonik_include_preamble "${SLON_ETC}/$INSTANCE.preamble"

# Other nodes
for (( i=1 ; i <= taille_nod ; i+=4 )); do
  NODE1=${NODE[$i]}
  BASE1=${NODE[$i+1]}
  HOST1=${NODE[$i+2]}
  PORT1=${NODE[$i+3]}

# Links between one node and others (higher numbers)
  for (( j=i ; j <= taille_nod ; j+=4 )); do
	if [ $i -ne $j ]; then
	  NODE2=${NODE[$j]}
	  BASE2=${NODE[$j+1]}
	  HOST2=${NODE[$j+2]}
	  PORT2=${NODE[$j+3]}

	  tpl_slonik_try_drop_path $NODE1 $NODE2
	  tpl_slonik_success_error "Success" "Failed !"

	  cat <<EOF
echo 'Store path $NODE1 <-> $NODE2:';
try {
EOF
	  tpl_slonik_store_path "$NODE1" "$NODE2" "$BASE1" "$HOST1" "$PORT1"
	  tpl_slonik_store_path "$NODE2" "$NODE1" "$BASE2" "$HOST2" "$PORT2"
	  echo "}"

	  tpl_slonik_success_error "$(gettext 'Success !!!')" "$(gettext 'Failed')"

	fi
  done
done

tpl_sh_slonik_end_eof

exit 0
# End Real work
#################################################
