#!/bin/bash
# slony_propagate.sh
# Auteur : Stéphane Schildknecht
# 2009-05-11

# Script de propagation de requêtes SQL à l'ensemble des noeuds sans
# passer par Slony
## EN: Propagation of an SQL script, outside slony

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo "$filename"
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo $(gettext      "Execution of a SQL script on every node, outside of slony")
  echo $(gettext      "Options:")
  echo -e $(gettext   "\\t-h, --help\\tPrint this message")
  echo -e $(gettext   "\\t-c, --cluster\\tReplication cluster name")
  echo -e $(gettext   "\\t-f, --file\\tThe SQL script")
  echo ""
}

TEMP=`getopt -n $0 -o c:f: -l help,cluster:,file: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-f|--file)
	  shift
	  FILE="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" -o x"$FILE" = "x" ]; then
  slhelp
  exit 1
fi
# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

CLUSTERNAME=$CLUSTER

# Constitution d'un tableau à deux dimensions.
node $CLUSTER

tpl_sh_shabang

# Exécution du script
for (( i=0 ; i < taille_nod ; i+=4 )); do
  cat << EOF
echo "#"
echo "Base ${NODE[$i+2]} - Node ${NODE[$i+1]}"
$PG/bin/psql -U ${SLONY_USER} ${NODE[$i+2]} -h ${NODE[$i+3]} -p ${NODE[$i+4]} -f $FILE

if [ \$? -ne 0 ]; then
  error "Propagation"
  echo "An error occured."
  exit 1
fi
EOF
  echo "##"
done
echo "exit 0"
exit 0
# End Real work
#################################################
