#!/bin/bash
# Auteur : Stephane Schildknecht
# 2007-01-15
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#

# slony_repstat.sh
# Script de vérification de la synchronisation d'un esclave

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo $(eval_gettext "\$filename")
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo -e $(gettext "\\tOptions:")
  echo -e $(gettext "\\t\\t-h, --help\\t\\tPrint this help")
  echo -e $(gettext "\\t\\t-c, --cluster\\t\\tThe replication cluster name")
  echo ""
}

TEMP=`getopt -n $0 -o c:,h -l help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

INSTANCE=""
while [ $# -ge 1 ]; do
  case "$1" in
	--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  INSTANCE="$1"
	  ;;
	--)
	  shift
	  NODE1=$1
	  NODE2=$2
	  break
	  ;;
	*) $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$INSTANCE" = "x" ]; then
  slhelp
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $INSTANCE
replication_exist $INSTANCE
# End Sanity checks
#################################################

#################################################
# Begin Real work

if [[ -n $NODE1 && -n $NODE2 ]]; then
            while read line
            do
		echo $line | grep -v "^#" | grep "^$INSTANCE\b" > /dev/null
		if [ $? -eq 0 ] ; then
		    BASE=( $line )
                    if [ ${BASE[1]} -eq $NODE1 ]; then
			MASTERNODE=${BASE[1]} #Numéro du noeud
                        MASTERBASE=${BASE[2]} #Base
                        MASTERHOST=${BASE[3]} #Host
                        MASTERPORT=${BASE[4]} #Port
		    elif [ ${BASE[1]} -eq $NODE2 ]; then
                        SLAVENODE=${BASE[1]} #Numéro du noeud
                        SLAVEBASE=${BASE[2]} #Base
                        SLAVEHOST=${BASE[3]} #Host
                        SLAVEPORT=${BASE[4]} #Port
		    fi
                fi
            done < $SLON_ETC/bases.h

    echo " "
    if [[ x$LANG = xfr* ]]; then
	echo "$INSTANCE : décalage entre le maître et l'esclave"
    else
	echo "$INSTANCE: Lag between slave and master"
    fi
    $PG/bin/psql $MASTERBASE -U ${SLONY_USER} -h $MASTERHOST -p $MASTERPORT -t -c "select st_lag_num_events||' SYNC et '||st_lag_time from \"_$INSTANCE\".sl_status where st_received=$NODE2;"
    if [[ x$LANG = xfr* ]]; then
	echo "Avec un décalage <=1, il est possible d'effectuer une bascule de la réplication."
    else
	echo "If lag <= 1, you can switchover."
    fi

else
    node $INSTANCE
    for SETID in `grep "^$INSTANCE\b" $SLON_ETC/relations.h | grep -v "^#" | awk '{print \$2}' | sort -u`; do
	relation $SETID
	echo "SET $SETID :"
	MASTERNODE=${NODE[${INDEX[$MASTER]}]}   #Numéro du noeud
	MASTERBASE=${NODE[${INDEX[$MASTER]}+1]} #Base
	MASTERHOST=${NODE[${INDEX[$MASTER]}+2]} #Host
	MASTERPORT=${NODE[${INDEX[$MASTER]}+3]} #Port
	$PG/bin/psql $MASTERBASE -U ${SLONY_USER} -h $MASTERHOST -p $MASTERPORT -t -c "select 'Noeud '||st_received||' : '||st_lag_num_events||' SYNC et '||st_lag_time from \"_$INSTANCE\".sl_status order by st_received;"
    done
fi
exit 0
# End Real work
#################################################
