#!/bin/bash
# Auteur : Stephane Schildknecht
# 2007-05-22
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables

# slony_subscribe.sh
# Script de resouscription des noeuds, en fonction du fichier relations.h
## EN: Resubscribe nodes regarding relations.h
# Il est impératif que les fichiers ${SLON_ETC}/bases.h et
# ${SLON_ETC}/$CLUSTERNAME.preamble soient à jour.

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo $(eval_gettext "\$filename")
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo -e $(gettext "\\tRe-subscribing set regarding relations.h")
  echo -e $(gettext "\\tOptions:")
  echo -e $(gettext "\\t\\t-h, --help\\t\\tPrint this help")
  echo -e $(gettext "\\t\\t-c, --cluster\\t\\tThe replication cluster name")
  echo ""
}

TEMP=`getopt -n $0 -o c:,h -l help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" ]; then
  slhelp
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

# Création des tableaux
## EN: nodes array
node $CLUSTER

tpl_sh_shabang

SUPER=0
GREP_SET="grep \"^$CLUSTER\b\" $SLON_ETC/relations.h | grep -v \"^#\" | awk '{print \$2}' | sort -u"
for SETID in `eval $GREP_SET` ; do
  ## EN: relations array
  relation $SETID

# Pour toutes les relations, on souscrit SLAVE à MASTER
# Il est préférable d'attendre que SLAVE ait déjà souscrit, s'il doit être esclave-maître
# Double boucle pour les souscriptions
## EN: For every relation, SLAVE subscribes to MASTER
# In case SLAVE has to be provider, we wait for complete subscription.
# Double loop
  for (( i=1 ; i <= taille_rel ; i+=2 )); do
	mtr1=${REL[$i]}     #MAITRE
	slv1=${REL[$i+1]}  #ESCLAVE
	for (( j=1 ; j <= taille_rel ; j+=2 )); do
	  # Si mtr est slv d'un autre noeud
	  ## If mtr is already a slave
	  if [ ${REL[$j+1]} -eq ${REL[$i]} ]; then
		mtr=${INDEX[${REL[$j]}]}
		slv=${INDEX[${REL[$j+1]}]}
		tpl_sh_while_subscribe ${REL[$j+1]} ${REL[$j]} \
							   ${NODE[$mtr+1]} ${NODE[$mtr+2]} \
							   ${NODE[$mtr+3]} $CLUSTER \
							   ${NODE[$slv]} $SETID
	  fi
	done
	# On peut souscrire
	# OK, let's subscribe


	tpl_sh_slonik_begin_eof
	tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"
	tpl_slonik_subscribe_set $SETID $mtr1 $slv1 \
							 "Node $slv1 subscribes set $SETID on $mtr1: "
	tpl_slonik_success_error "Success" "Failed !"
	echo "exit 0;"
	tpl_sh_slonik_end_eof

  done
done


cat <<EOF
if [ \$? -ne 0 ]; then
  error "SUBSCRIBE SET" 3
  echo "An error occured."
  exit 1
fi
exit 0
EOF

exit 0
# End Real work
#################################################
