#!/bin/bash
# Auteur : Stéphane Schildknecht
# 2006-12-18
# Rev 2007-04-17
# Modifications :
#  - 20071214 Bernard Choppy
#    possibilite de lancer depuis n'importe ou
#    systematisation de l'utilisation des variables
#

# upgrade_slon.sh
# Script de montee de version de Slony1
# Nécessite une mise jour des schémas
## EN: Upgrading slony

# TODO : Modification du script pour utilisation avec
#        toute base de tout serveur

#################################################
# Begin initialise configuration
CDIR=`dirname $0`
pushd $CDIR/.. >> /dev/null
SLON=`pwd`
popd >> /dev/null

. $SLON/etc/slony_include.h
. $SLON_ETC/fonctions.sh
. $SLON_ETC/tpl_functions.sh

filename="$0"

export LD_LIBRARY_PATH=$PG/lib/
# End initialise configuration
#################################################

#################################################
# Begin help, getopt and handle case
slhelp() {
  echo $(eval_gettext "\$filename")
  echo ""
  echo $(eval_gettext "Usage: \$filename *options*")
  echo -e $(gettext "\\tUpgrading Slony")
  echo -e $(gettext "\\tOptions:")
  echo -e $(gettext "\\t\\t-h, --help\\t\\tPrint this help")
  echo -e $(gettext "\\t\\t-c, --cluster\\t\\tThe replication cluster name")
  echo ""
}

TEMP=`getopt -n $0 -o c:h -l help,cluster: -- "$@"`
if [ $? != 0 ] ; then
  slhelp
  exit 1
fi
eval set -- "$TEMP"

CLUSTER=""
while [ $# -ge 1 ]; do
  case "$1" in
	-h|--help)
	  HELP=1
	  slhelp
	  exit 0
	  ;;
	-c|--cluster)
	  shift
	  CLUSTER="$1"
	  ;;
	-d|--debug)
	  DEBUG=1
	  ;;
	--)
	  shift
	  break
	  ;;
	*)
	  echo $(gettext "Warning !")
	  slhelp
	  exit 1
	  ;;
  esac
  shift
done

if [ x"$CLUSTER" = "x" ]; then
  slhelp;
  exit 1
fi

# End help, getopt and handle case
#################################################

#################################################
# Begin Sanity checks
relbase_exist
preamble_exist $CLUSTER
replication_exist $CLUSTER
# End Sanity checks
#################################################

#################################################
# Begin Real work

tpl_sh_shabang
cat <<EOF
# First, we stop slon daemons
${SLON_OUTILS}/slony_ctl.sh -c ${CLUSTER} stop

# Then we build the slonik script
EOF
tpl_sh_slonik_begin_eof
tpl_slonik_include_preamble "${SLON_ETC}/$CLUSTER.preamble"

cat <<EOF

#--
# Mise à jours des schémas
## Call slonik procedure to upgrade
#--
try{
  echo 'Upgrade Slony:';
EOF

for NODE in `grep "^$CLUSTER\b" $SLON_ETC/bases.h | grep -v "^#" | awk '{print $2}'` ; do
  tpl_slonik_update_functions $NODE
done
echo "}"

tpl_slonik_success_error "$(gettext 'Success')" "$(gettext 'Failed !!!')"

echo "exit 0;"
tpl_sh_slonik_end_eof
cat << EOF

if [ \$? -ne 0 ]; then
  error "UPDATE" 3
  exit 1
fi

# Start the replication daemons
${SLON_OUTILS}/slony_ctl.sh -c ${CLUSTER} start

EOF

exit 0
# End Real work
#################################################
